import { useState, useEffect } from 'react';
import styled from 'styled-components';
// import { Table } from 'react-bootstrap';
import axios from 'axios';

import { PageLayout, PageHeaderWrapper } from '@/app/components/PageLayout';
import { PageTitle } from '@/common/components/page/PageTitle';
import { List } from '@/common/components/List';
import { ListHeader, ListHeaders } from '@/common/components/List/ListHeader';
import { TableListItem } from '@/common/components/List';
import {
  HeaderText,
  SortIconDown,
  SortIconUp,
} from '@/common/components/SortedListHeaders';
import { TextBig, TokenValue } from '@/common/components/typography';
import { BorderRad, Colors, Transitions } from '@/common/constants';

import { Column } from 'react-table';

import Loading from '../Loading';
import Table from './table/table';
import './bounties.css';

interface IBounty {
  id: any;
  title: string;
  description: string;
  format: string;
  openedDate: any;
  status: string;
  reward: string | number;
  manager: string[];
  links: string[];
}

const columns: Column[] = [
  {
    Header: 'ID',
    accessor: 'id',
  },
  {
    Header: 'Title',
    accessor: 'title',
  },
  {
    Header: 'Links',
    accessor: 'links',
    // TODO: format()
  },
  {
    Header: 'Reward',
    accessor: 'reward',
  },
  {
    Header: 'Manager, Co',
    accessor: 'manager',
  },
  {
    Header: 'Status/Grading',
    accessor: 'status',
  },
];

const JSTableComponent = styled.table`
  // border: 1px solid ${Colors.Black[100]};
  // background-color: ${Colors.White};
  transition: ${Transitions.all};
`;

const JSTableHeaderComponent = styled.thead`
  @media screen and (max-width: 800px) {
    display: none;
  }
`;

const JSTableHeaderRowComponent = styled.tr``;

const JSTableRowComponent = styled.tr`
  border: 1px solid ${Colors.Black[100]};
  border-radius: ${BorderRad.s};
  transition: ${Transitions.all};

  @media screen and (max-width: 800px) {
    display: block;
  }
`;

const JSTableHeaderCellComponent = styled.th`
  position: relative;
  align-items: center;
  align-content: center;
  font-size: 10px;
  line-height: 16px;
  font-weight: 700;
  color: ${Colors.Black[400]};
  text-transform: uppercase;
  text-align: left;
  user-select: none;
  cursor: pointer;
  padding-left: 16px;
`;

const JSTableCellComponent = styled.td`
  align-items: center;
  height: 72px;
  justify-content: left;
  padding-right: 20px;
  padding-left: 16px;

  font-size: 16px;
  line-height: 24px;

  
  @media screen and (max-width: 800px) {
    display: block;
    
    &:before {
      content: attr(aria-label);
      float: left;
      font-weight: bold;
    }
  }
`;

const tableComponents = {
  Table: JSTableComponent,
  TableHeader: JSTableHeaderComponent,
  TableHeaderRow: JSTableHeaderRowComponent,
  TableRow: JSTableRowComponent,
  TableHeaderCell: JSTableHeaderCellComponent,
  TableBody: 'tbody',
  TableCell: JSTableCellComponent,
};

function Bounties() {
  const [bounties, setBounties] = useState<IBounty[] | null>(null);

  const fetchBounties = async () => {
    const response = await axios.get<{ activeBounties: IBounty[] }>(
      `https://raw.githubusercontent.com/Joystream/community-repo/master/bounties/bounties-status.json`
    );

    setBounties(response.data?.activeBounties);
  };

  useEffect(() => {
    fetchBounties();
  }, []);

  if (!bounties) return <Loading target={`bounties`} />;

  return (
    <PageLayout
      header={
        <PageTitle>Bounties</PageTitle>}
      main={
        <div className="Bounties m-2 p-1 bg-light">
          <Table
            id="testTable"
            columns={columns}
            data={bounties}
            tableComponents={tableComponents}
            SortIconDown={SortIconDown}
            SortIconUp={SortIconUp}
            getCellProps={(cell: any) => ({
              'aria-label': cell.column.Header
            })}
          />
        </div>
      }
    />
  );
}
export default Bounties;
