import React from "react";
import styled from "styled-components";
import { MemberBox, Spinner } from "..";
import ElectionStatus from "./ElectionStatus";
import {
  Paper,
  Grid,
  makeStyles,
  Theme,
  createStyles,
  Toolbar,
  Typography,
  AppBar,
  GridSize,
} from "@material-ui/core";

import {
  ContentWithTabs,
  RowGapBlock,
} from "@/common/components/page/PageContent";

import { Label } from "@/common/components/typography";
import { CountBadge } from "@/common/components/CountBadge";
// import { BorderRad, Colors, Shadows } from '../../pioneer/packages/ui/src/common/constants';

import { Council, Post, ProposalDetail, Status } from "../../types";
import { BorderRad, Colors, Shadows, Transitions } from "@/common/constants";
import { MemberInfo } from "@/memberships/components";
import { Worker } from "@/working-groups/components/Worker";

const useStyles = makeStyles((theme: Theme) =>
  createStyles({
    root: {
      flexGrow: 1,
      backgroundColor: "#4038FF",
    },
    title: {
      textAlign: "left",
      flexGrow: 1,
    },
  })
);

export const DashboardPanel = styled.div`
  position: relative;
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-row-gap: 24px;
  width: 100%;
  height: fit-content;
`;

export const BorderBlock = styled.div`
  display: grid;
  position: relative;
  padding: 16px;
  border: 1px solid ${Colors.Black[100]};
  border-radius: ${BorderRad.s};
  transition: ${Transitions.all};
`;

const CouncilGrid = (props: {
  councilElection?: any;
  councils: Council[];
  proposals: ProposalDetail[];
  posts: Post[];
  validators: string[];
  status: Status;
  electionPeriods: number[];
  gridSize: GridSize;
}) => {
  const { getMember, councils, domain, posts, proposals, status, gridSize } =
    props;
  const { council, election } = status;
  const classes = useStyles();

  const sortCouncil = (consuls) =>
    consuls.sort((a, b) =>
      (a.member.handle || "").localeCompare(b.member.handle || "")
    );

  return (
    <DashboardPanel>
      <RowGapBlock gap={36}>
        <BorderBlock>
          <ContentWithTabs>
            <Label>
              Councils <CountBadge count={council?.consuls?.length ?? 0} />{" "}
            </Label>
            <WorkerWrap>
              <ContentWithTabs>
                {council?.consuls?.length ? (
                  sortCouncil(council.consuls).map((c: any) => (
                    <MemberInfo member={getMember(c.member.handle)} />
                  ))
                ) : (
                  <Spinner />
                )}
              </ContentWithTabs>
            </WorkerWrap>
          </ContentWithTabs>
        </BorderBlock>
      </RowGapBlock>
    </DashboardPanel>
  );
};

const WorkerWrap = styled.div`
  display: grid;
  grid-template-columns: 1fr;
  grid-column-gap: 8px;
`;

export default CouncilGrid;
