import React from "react";
import Council from "./Council";
import Forum from "./Forum";
import Proposals from "./Proposals";
import Validators from "../Validators";
import { IState } from "../../types";
import { Container, Grid } from "@material-ui/core";

import { PageLayout, PageHeaderWrapper } from "@/app/components/PageLayout";
import { RowGapBlock } from "@/common/components/page/PageContent";
import { PageTitle } from "@/common/components/page/PageTitle";

interface IProps extends IState {
  toggleStar: (a: string) => void;
  toggleFooter: () => void;
}

const Dashboard = (props: IProps) => {
  const {
    getMember,
    toggleStar,
    councils,
    members,
    nominators,
    posts,
    proposals,
    rewardPoints,
    threads,
    tokenomics,
    status,
    stars,
    stashes,
    stakes,
    validators,
    domain,
  } = props;

  return (
    <>
      <PageLayout
        header={
          <RowGapBlock gap={24}>
            <PageHeaderWrapper>
              <PageTitle>Dashboard</PageTitle>
              <Validators
                toggleStar={toggleStar}
                councils={councils}
                members={members}
                posts={posts}
                proposals={proposals}
                nominators={nominators}
                validators={validators}
                stashes={stashes}
                stars={stars}
                stakes={stakes}
                rewardPoints={rewardPoints}
                tokenomics={tokenomics}
                status={status}
              />
              <Council
                getMember={getMember}
                councils={councils}
                council={status.council}
                posts={posts}
                proposals={proposals}
                stars={stars}
                status={status}
                validators={validators}
                domain={domain}
                gridSize={6}
              />
            </PageHeaderWrapper>
          </RowGapBlock>
        }
        main={<>test</>}
      />
    </>
  );
};

export default Dashboard;
