import React, { useState } from 'react';
import styled from 'styled-components';

import { BlockIcon, BlockIconStyles } from '@/common/components/icons';

import { PageLayout, PageHeaderWrapper } from '@/app/components/PageLayout';
import { RowGapBlock } from '@/common/components/page/PageContent';
import { PageTitle } from '@/common/components/page/PageTitle';

import {
  BlockDurationStatistics,
  MultiValueStat,
  Statistics,
} from '@/common/components/statistics';
import {
  MultiStatisticItem,
  StatsBlock,
  StatisticItem,
  StatisticLabel,
  StatisticItemProps,
  StatisticItemSpacedContent,
  StatisticHeader,
  StatisticHeaderProps,
  TotalValue,
} from '@/common/components/statistics';
import {
  Select,
  SelectedOption,
  Option,
  OptionsListComponent,
} from '@/common/components/selects';
import { DurationValue } from '@/common/components/typography/DurationValue';
import { TextInlineSmall } from '@/common/components/typography';
import { ColumnGapBlock } from '@/common/components/page/PageContent';
import { AN_HOUR, A_DAY, A_MINUTE, A_WEEK, Fonts } from '@/common/constants';
import {
  Checkbox,
  InlineToggleWrap,
  InputComponent,
  InputText,
  InputTextarea,
  Label,
  LabelLink,
  ToggleCheckbox,
} from '@/common/components/forms';

import ValidatorRewards from './ValidatorRewards';
import Loading from '../Loading';

// TODO OPTIMIZE fetch live
import {
  getStart,
  getEnd,
  payoutInterval,
  mintTags,
  salaries,
} from './config.ts';

interface IProps {
  mints: any[];
  tokenomics?: any;
  validators: string[];
  lastReward: number;
  history: any;
}

interface IState {
  role: string;
  salary: number;
  payout: number; // for validators
  [key: string]: number | string;
}

class Mint extends React.Component<IProps, IState> {
  constructor(props: IProps) {
    super(props);

    this.state = { role: '', salary: 0 };
    this.setRole = this.setRole.bind(this);
    this.handleChange = this.handleChange.bind(this);
  }

  componentDidMount() {
    this.setRole({ value: 'consul' });
  }

  setRole(e: any) {
    // const role = e.target.value;
    const role = e.value;
    this.setState({ role, salary: salaries[role] });
  }

  handleChange(e: {
    preventDefault: () => void;
    target: { name: string; value: any };
  }) {
    e.preventDefault();
    this.setState({ [e.target.name]: parseInt(e.target.value) });
  }

  formatMint(mint: { capacity: number; total_minted: number }) {
    if (!mint) return `loading ..`;
    const { capacity, total_minted } = mint;
    const current = (capacity / 1000000).toFixed(1);
    const total = (total_minted / 1000000).toFixed(1);
    return `${current} M of ${total} M tJOY`;
  }

  render() {
    const { status, tokenomics, validators, payout, mints } = this.props;
    if (!tokenomics) return <Loading target="tokenomics" />;
    if (!status.council) return <Loading target="council round" />;

    const { round } = status.council;
    const start = getStart(round);
    const end = getEnd(round);

    const { role, salary } = this.state;
    const { price } = tokenomics;
    const rate = Math.floor(+price * 100000000) / 100;
    const blocks = end - start;

    const options = Object.keys(salaries).map((r: string) => ({
      key: r,
      value: r,
      label: r,
    }));

    console.log(options);

    return (
      <>
        <PageLayout
          header={
            <RowGapBlock gap={24}>
              <PageHeaderWrapper>
                <PageTitle>Mints</PageTitle>
              </PageHeaderWrapper>
            </RowGapBlock>
          }
          main={
            <>
              <Form>
                <InputComponent required inputSize="l">
                  <JSSelect onChange={this.setRole} options={options} />
                </InputComponent>
              </Form>
              <JSStatistics>
                {/* <StatisticItem title="Validators" size="s"> */}
                
                <JSStatsBlock size="s">
                  <StatisticHeader title="Rewards" />
                  <StatsContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>
                        Reward (JOY / {payoutInterval} blocks)
                      </StatisticLabel>
                      {salary}
                    </StatisticItemSpacedContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>
                        Reward (USD / {payoutInterval} blocks)
                      </StatisticLabel>
                      {price * salary}
                    </StatisticItemSpacedContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>
                        Reward (JOY) / {blocks} blocks
                      </StatisticLabel>
                      {(blocks / payoutInterval) * salary}
                    </StatisticItemSpacedContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>
                        Reward (USD) / {blocks} blocks
                      </StatisticLabel>
                      {(blocks / payoutInterval) * salary * price}
                    </StatisticItemSpacedContent>
                  </StatsContent>
                </JSStatsBlock>
                <JSStatsBlock size="s">
                  <StatisticHeader title="Roles" />
                  <StatsContent>
                    {[2, 3, 4].map((m) => (
                      <StatisticItemSpacedContent key={m}>
                        <StatisticLabel>{mintTags[m]}</StatisticLabel>
                        {this.formatMint(mints[m])}
                      </StatisticItemSpacedContent>
                    ))}
                  </StatsContent>
                </JSStatsBlock>
                <JSStatsBlock size="s">
                  <StatisticHeader title="Blocks" />
                  <StatsContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>Start block</StatisticLabel>
                      {start}
                    </StatisticItemSpacedContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>End block</StatisticLabel>
                      {end}
                    </StatisticItemSpacedContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>Blocks</StatisticLabel>
                      {blocks}
                    </StatisticItemSpacedContent>
                  </StatsContent>
                </JSStatsBlock>
                <JSStatsBlock size="s">
                  <StatisticHeader title="Additional" />
                  <StatsContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>Token value</StatisticLabel>
                      {`${rate} $ / 1 M JOY`}
                    </StatisticItemSpacedContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>End block</StatisticLabel>
                      {end}
                    </StatisticItemSpacedContent>
                    <StatisticItemSpacedContent>
                      <StatisticLabel>Blocks</StatisticLabel>
                      {blocks}
                    </StatisticItemSpacedContent>
                  </StatsContent>
                </JSStatsBlock>
              </JSStatistics>
            </>
          }
        />
      </>
    );
  }
}

// =====================================================

const Form = styled.div`
  margin-bottom: 24px;
`;

const JSStatistics = styled(Statistics)`
  display: grid;
  grid-template-columns: repeat(4, 1fr);

  @media only screen and (max-width: 1600px) {
    grid-template-columns: repeat(2, 1fr);
  }

  @media only screen and (max-width: 1000px) {
    grid-template-columns: repeat(1, 1fr);
  }
`;

const JSStatsBlock = styled(StatsBlock)`
  width: 100%;
`;

// =====================================================

const BlocksInfo = styled(ColumnGapBlock)`
  margin-top: 2px;
`;

const ItemRow = styled(StatisticItemSpacedContent)`
  justify-content: start;
`;

const NumberOfBlocks = styled(TextInlineSmall)`
  font-family: ${Fonts.Grotesk};
  ${BlockIconStyles} {
    vertical-align: middle;
  }
`;

export const StatsContent = styled.div`
  margin-top: auto;
`;

interface Props {
  options: any[];
  onChange: (option: any) => void;
}

const OptionList = React.memo(({ options, onChange }: Props) => (
  <OptionsListComponent>
    {options.map((option) => (
      <Option
        key={option.key || option.id}
        onClick={() => onChange && onChange(option)}
      >
        {option.label}
      </Option>
    ))}
  </OptionsListComponent>
));

const renderSelected = (option: any) => (
  <SelectedOption>{option.label}</SelectedOption>
);

const JSSelect = ({ options, onChange }: { options: any[], onChange: Function }) => {
  const [selected, setSelected] = useState(options[0]);

  const handleChange = (item: any, cb: any) => {
    setSelected(item);
    onChange && onChange(item);
    cb();
  };

  return (
    <Select
      selected={selected}
      onChange={handleChange}
      // disabled={disabled}
      renderSelected={renderSelected}
      placeholder="Select account or paste account address"
      renderList={(onOptionClick) => (
        <OptionList onChange={onOptionClick} options={options} />
      )}
      // onSearch={(search) => setSearch(search)}
    />
  );
};

export default Mint;
